import QtQuick 1.1
import com.nokia.meego 1.0
import "./js/recitations.js" as Recitations
import "./js/settings.js" as Setting

Page {
    tools: commonTools
    TopBar {
        id:header
        anchors {top:parent.top;left:parent.left;right:parent.right}
        title: "Settings"
    }
    Flickable {
        id: flickable
        anchors {top:header.bottom;left:parent.left;right:parent.right; bottom:parent.bottom}
        flickableDirection: Flickable.VerticalFlick
            Label {
                id: textSample
                text: "بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ"
                font.family: quranFont.name;
                font.pixelSize: fontsize
                anchors.top:parent.top
                anchors.left:parent.left
                anchors.right: parent.right
                verticalAlignment: Text.AlignVCenter;
                horizontalAlignment: Text.AlignHCenter;
            }
            Item {
                id: erste
                anchors.top: textSample.bottom
                height: 80
                width: parent.width
                Label {
                    id: neightbour
                    text: "Fontsize:"
                    anchors.left:parent.left
                    anchors.leftMargin: 30
                    anchors.verticalCenter: parent.verticalCenter
                }
                Slider {
                    anchors {left:neightbour.right;top:parent.top; right:parent.right;bottom: parent.bottom}
                    id:fontSizeSlider
                    stepSize:1
                    valueIndicatorVisible: true
                    minimumValue:25
                    maximumValue:50
                    value: Setting.get("fontsize")
                    onPressedChanged:{
                       if(pressed != true)
                           Setting.set("fontsize",value)
                    }
                    onValueChanged:{
                        fontsize = value
                    }
                }
            }
            Item {
                id: dritte
                anchors.top: erste.bottom
                width: parent.width
                Label {
                    id: neightbour2
                    text: "Open Last Read"
                    anchors.left:parent.left
                    anchors.leftMargin: 30
                    anchors.verticalCenter: parent.verticalCenter
                }

                Switch {
                    anchors.right:parent.right
                    anchors.rightMargin: 30
                    anchors.verticalCenter: parent.verticalCenter
                    id: saveReadSwitch
                    checked: openLastRead
                    onCheckedChanged: {
                        Setting.set("openLastRead",checked)
                        openLastRead = checked;
                    }
                }
            }
            Item {
                id: zweite
                anchors.top: dritte.bottom
                width: parent.width
                ListModel {id:recitationModel }
                SelectionDialog {
                    id: reciSelection
                    titleText: "Select Recitator"
                    selectedIndex: Setting.get("recitator")
                    model: recitationModel
                    onSelectedIndexChanged:
                    {
                        Setting.set("recitator",reciSelection.selectedIndex)
                        recitator = reciSelection.selectedIndex+1
                    }
                    Component.onCompleted: {
                        for ( var index in Recitations.recitations )
                        {
                            recitationModel.append({"name" : Recitations.recitations[index].name+" ("+ Recitations.recitations[index].bitrate+")"});
                        }
                    }

                }
                Button {
                    anchors.horizontalCenter: parent.horizontalCenter
                    text: Recitations.recitations[recitator].name
                    onClicked: {
                        reciSelection.open();
                    }
                }
            }
    }
    ToolBarLayout {
        id: commonTools
        visible: true
        ToolIcon {
            platformIconId: "toolbar-back"
            //anchors.left: (parent === undefined) ? undefined : parent.left
            onClicked: appWindow.pageStack.pop();
        }
    }

    Menu {
        id: myMenu
        visualParent: pageStack
        MenuLayout {
            MenuItem { text: qsTr("Sample menu item") }
        }
    }
}
