import Qt 4.7
import QtQuick 1.1
import com.nokia.meego 1.0
import QtMultimediaKit 1.1
import "./js/settings.js" as Setting

Page {
    property string stitle;
    property int sura : 1;
    property string saya;
    tools: commonTools
    XmlListModel {
        source: "./data/quran-simple-enhanced.xml"
        query: "/quran/sura[@index='"+sura+"']/aya"

        id:xmlModel
        XmlRole{ name: "index"; query: "@index/string()"}
        XmlRole{ name: "content"; query: "@text/string()"}
    }

    ListView {
        id: suraList
        model: xmlModel
        delegate: suraDelegate
        currentIndex: playingSura != sura ? -1 : playingSuraAya-1
        spacing: 1
        clip:true
        cacheBuffer: 30000 // contactsModel.count * 81 --> this should work too.
        anchors {left:parent.left; top:header.bottom; right:parent.right;bottom:parent.bottom;}
        section.property: "index"
        section.delegate:
            Rectangle {
                width: parent.width
                height: 1
                color: "lightgray"
                Text {
                    text: section
                    font.family: quranFont.name;
                    font.pixelSize: 12
                    color: "gray"
                    anchors {left:parent.left;top:parent.top;}
                }
            }
        highlight:  Rectangle { width:appWindow.width; color:"lightsteelblue"; opacity: 0.7 }
        Component.onCompleted:{
            fast.listViewChanged()
        }
        property real contentBottom: contentY + height
        Component {
            id: suraDelegate
                Label {
                    text:content;
                    //anchors.horizontalCenter: parent.horizontalCenter
                    verticalAlignment: Text.AlignVCenter;
                    horizontalAlignment: Text.AlignHCenter;
                    width: parent.width
                    font.family: quranFont.name;
                    font.pixelSize: fontsize
                    MouseArea {
                        anchors.fill: parent
                        onClicked:{
                            saya = index
                            sheet.open()
                        }
                    }
                }
        }
        FastScroll {
            id: fast
            listView: suraList
        }
        onCountChanged: count > 0 ? loading.visible = false : loading.visible = true
        onCurrentSectionChanged: {
            Setting.set("lastReadAya",currentSection)
            lastReadAya = currentSection
        }
    }
    TopBar {
        id:header
        anchors {top:parent.top;left:parent.left;right:parent.right}
        title: stitle
    }

    ToolBarLayout {
        id: commonTools
        visible: true
        ToolIcon {
            platformIconId: "toolbar-back"
            //anchors.left: (parent === undefined) ? undefined : parent.left
            onClicked: appWindow.pageStack.pop();
        }
        ToolButton {
            /*
            ProgressBar {
                id: progressBar
                width: parent.width
                anchors {top:parent.top;left:parent.left}
                minimumValue: 0
                maximumValue: 1
                value: quranAya.bufferProgress
            }
            */
            iconSource: quranAya.paused ? "image://theme/icon-m-lockscreen-mediacontrol-play"  :"image://theme/icon-m-lockscreen-mediacontrol-pause"
            text: playingSuraName != '' ? (quranAya.paused ? stitle : playingSuraName ) : stitle
            onClicked:{
                if(quranAya.paused == true) {
                    if(playingSura != sura) {
                        quranAya.pause();
                    }
                    playingSuraName = stitle
                    playingSura= sura
                    playingSuraAya = 1
                    ayac=suraList.count
                    quranAya.play();
                } else
                    quranAya.pause();
            }
        }
        ToolIcon {
            platformIconId: "toolbar-settings"
            //anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: appWindow.pageStack.push(Qt.resolvedUrl("SettingsPage.qml"));
        }
    }

    Sheet {
        id: sheet

        //acceptButtonText: "Save"
        rejectButtonText: "Cancel"

        content: Flickable {
            anchors.fill: parent
            anchors.leftMargin: 10
            anchors.topMargin: 10
            flickableDirection: Flickable.VerticalFlick
            Label {
                    id:arabictxt
                    text:saya > 0 ? xmlModel.get(saya-1).content : 0;
                    anchors.horizontalCenter: parent.horizontalCenter
                    verticalAlignment: Text.AlignVCenter;
                    horizontalAlignment: Text.AlignHCenter;
                    width: parent.width-30
                    font.family: quranFont.name;
                    font.pixelSize: 25
            }
            Rectangle {
                id:seperator
                anchors {top:arabictxt.bottom;left:parent.left;right:parent.right;leftMargin: 10;rightMargin:30}
                height: 1
                color: "lightgray"
            }
            Label {
                    id:translation
                    text: "Coming Soon translation of every aya"
                    font.bold: true;
                    anchors {top:seperator.bottom;}
                    anchors.horizontalCenter: parent.horizontalCenter
                    verticalAlignment: Text.AlignVCenter;
                    horizontalAlignment: Text.AlignHCenter;
                    width: parent.width-30
                    font.pixelSize: 25
            }

        }
        //onAccepted: myButton.text = "Accepted!"
        //onRejected: myButton.text = "Rejected!"
    }
    Component.onCompleted: {
        Setting.set("lastReadSura",sura)
        Setting.set("lastReadName",stitle)
        lastReadSura = sura
        lastReadName = stitle
        if(openLastRead)
            suraList.positionViewAtIndex(lastReadAya, ListView.Beginning);
    }
}
