import QtQuick 1.1
import com.nokia.meego 1.0

Page {
    tools: commonTools
    XmlListModel {
        source: "./data/quran-data.xml"
        query: "/quran/suras/sura"

        id:xmlModel
        XmlRole{ name: "index"; query: "@index/string()"}
        XmlRole{ name: "name"; query: "@name/string()"}
        XmlRole{ name: "tname"; query: "@tname/string()"}
        XmlRole{ name: "start"; query: "@start/number()"}
        XmlRole{ name: "ayas"; query: "@ayas/number()"}
    }

    ListView {
        id: surasList
        model: xmlModel
        delegate: suraDelegate
        spacing: 1
        clip:true
        cacheBuffer: 30000 // contactsModel.count * 81 --> this should work too.
        anchors {left:parent.left; top:header.bottom; right:parent.right;bottom:parent.bottom;}
        section.property: "tname"
        section.delegate:
            Rectangle {
                width: parent.width-40
                anchors.horizontalCenter: parent.horizontalCenter
                height: 1
                color: "lightgray"
            }
        Component.onCompleted: fast.listViewChanged()
        property real contentBottom: contentY + height
        Component {
            id: suraDelegate
            Item{
                id:singleListItem
                height: 80; width: parent.width
                 Rectangle { anchors.fill:parent; color:"lightsteelblue"; opacity: 0.7; visible: playingSura == index ? true : false }
                Row{
                    anchors.fill: parent
                    spacing: 12
                    anchors.topMargin: 10
                    anchors.leftMargin: 10
                    anchors.verticalCenter: parent.verticalCenter
                    Image {
                        id: suraImage
                        source: "image://theme/icon-m-common-presence-online"
                        height: 64
                        width: 64
                        Text {
                            text:index;
                            font.bold: true;
                            verticalAlignment: Text.AlignVCenter;
                            horizontalAlignment: Text.AlignHCenter;
                            anchors.fill: parent;
                            font.pixelSize: 25
                            color:"white"
                            visible: playingSura == index ? false : true
                        }
                        Image {
                            id: playingImg
                            source: "image://theme/icon-m-lockscreen-mediacontrol-play"
                            anchors.verticalCenter: parent.verticalCenter
                            anchors.horizontalCenter: parent.horizontalCenter
                            visible: playingSura == index ? true : false
                        }
                    }
                    Column{
                        width: parent.width - 80
                        Label {
                            id: sura_name
                            text:name
                            font.pointSize:8
                            elide: Text.ElideRight
                            width: parent.width -16
                            font.bold: true
                            height: 24
                        }
                        Label {
                            id:sura_trans
                            text: tname
                            font.pixelSize: 20
                            color: "gray"
                            width: parent.width -16
                            elide: Text.ElideRight
                            height: 24
                            clip: true
                        }
                    }
                }
                MouseArea {
                    anchors.fill: parent
                    onClicked: {
                        appWindow.pageStack.push(Qt.resolvedUrl("SuraPage.qml"), {sura: index, stitle: name })
                    }
                }
             }
        }
        FastScroll {
            id: fast
            listView: surasList
        }
        onCountChanged: count > 0 ? loading.visible = false : loading.visible = true
    }
    TopBar {
        id:header
        anchors {top:parent.top;left:parent.left;right:parent.right}
        title: "Select Sura"
    }

    ToolBarLayout {
        id: commonTools
        visible: true
        ToolIcon {
            platformIconId: "toolbar-back"
            //anchors.left: (parent === undefined) ? undefined : parent.left
            //onClicked: appWindow.pageStack.pop();
        }
        ToolButton {
            iconSource: quranAya.paused ? "image://theme/icon-m-lockscreen-mediacontrol-play"  :"image://theme/icon-m-lockscreen-mediacontrol-pause"
            text: playingSuraName
            visible: playingSuraName != '' ? true : false
            onClicked:{
                if(quranAya.paused == true) {
                    //console.log(quranAya.source)
                    quranAya.play();
                } else
                    quranAya.pause();
            }
        }
        ToolIcon {
            platformIconId: "toolbar-settings"
            //anchors.right: (parent === undefined) ? undefined : parent.right
            onClicked: appWindow.pageStack.push(Qt.resolvedUrl("SettingsPage.qml"));
        }
    }
    onStatusChanged: {
        if(status == PageStatus.Active) {
            if(opend) {
                if(openLastRead) {
                    appWindow.pageStack.push(Qt.resolvedUrl("SuraPage.qml"), {sura: lastReadSura, stitle: lastReadName })
                }
                opend = false;
            }
        }
    }
/*
    Menu {
        id: myMenu
        visualParent: pageStack
        MenuLayout {
            MenuItem { text: qsTr("Sample menu item") }
        }
    }
    */
}
